Changelog
=========


v0.4.0-pre2 (2022-10-04)
------------------------

All API components are now in a reasonably stable state, code has been
reorganized and docstrings updated.  Next steps will include polishing
docstrings and generalizing some of the functionality, but should leave the
central API components untouched.

Also, Swyft has a logo now.


v0.4.0-pre1 (2022-08-25)
------------------------

Initial alpha release of Swyft based on pytorch-lightning.
